aboutsummaryrefslogtreecommitdiff
path: root/views/default/layouts/module.php
diff options
context:
space:
mode:
Diffstat (limited to 'views/default/layouts/module.php')
-rw-r--r--views/default/layouts/module.php21
1 files changed, 13 insertions, 8 deletions
diff --git a/views/default/layouts/module.php b/views/default/layouts/module.php
index 8c74aae57..db940aedc 100644
--- a/views/default/layouts/module.php
+++ b/views/default/layouts/module.php
@@ -2,10 +2,11 @@
/**
* Elgg module layout
*
* @uses $vars['header'] HTML content of the header
* @uses $vars['body'] HTML content of the body
* @uses $vars['footer'] HTML content of the footer
* @uses $vars['class'] Optional additional class for module
*/
$header = elgg_get_array_value('header', $vars, '');
@@ -18,8 +19,14 @@ if ($additional_class) {
$class = "$class $additional_class";
}
+$header_class = 'elgg-header';
+$additional_class = elgg_get_array_value('header_class', $vars, '');
+if ($additional_class) {
+ $header_class = "$header_class $additional_class";
+}
+
if ($header) {
- $header = "<div class=\"elgg-header\">$header</div>";
+ $header = "<div class=\"$header_class\">$header</div>";
}
if ($footer) {
@@ -30,9 +37,7 @@ echo <<<HTML
<div class="$class">
<div class="elgg-inner">
$header
- <div class="elgg-body">
- $body
- </div>
+ <div class="elgg-body">$body</div>
$footer
</div>
</div>
@@ -2,10 +2,11 @@
* Elgg module layout
*
- * @uses $vars['header'] HTML content of the header
- * @uses $vars['body'] HTML content of the body
- * @uses $vars['footer'] HTML content of the footer
- * @uses $vars['class'] Optional additional class for module
+ * @uses $vars['header'] HTML content of the header
+ * @uses $vars['body'] HTML content of the body
+ * @uses $vars['footer'] HTML content of the footer
+ * @uses $vars['class'] Optional additional class for module
+ * @uses $vars['header_class'] Optional additional class for header
*/
$header = elgg_get_array_value('header', $vars, '');